@@ -36,49 +36,9 @@
 #include "chart.h"
 #include "element.h"
 #include "load.h"
-#include "aux.h"
+#include "misc.h"
 
 
-//=====================================================================
-//      Auxiliary callbacks
-//=====================================================================
-
-void
-on_circuitfile_load_selected(GtkButton *button, gpointer user_data)
-{
-  strcpy(pref.last_el_file,
-         gtk_file_selection_get_filename(GTK_FILE_SELECTION(user_data)));
-  load_circuit(pref.last_el_file);
-  save_file_paths();
-}
-
-void
-on_circuitfile_save_selected(GtkButton *button, gpointer user_data)
-{
-  strcpy(pref.last_el_file,
-         gtk_file_selection_get_filename(GTK_FILE_SELECTION(user_data)));
-  save_circuit(pref.last_el_file);
-  save_file_paths();
-}
-
-void
-on_loadfile_load_selected(GtkButton *button, gpointer user_data)
-{
-  strcpy(pref.last_ld_file,
-         gtk_file_selection_get_filename(GTK_FILE_SELECTION(user_data)));
-  load_loads(pref.last_ld_file);
-  save_file_paths();
-}
-
-void
-on_loadfile_save_selected(GtkButton *button, gpointer user_data)
-{
-  strcpy(pref.last_ld_file,
-         gtk_file_selection_get_filename(GTK_FILE_SELECTION(user_data)));
-  save_loads(pref.last_ld_file);
-  save_file_paths();
-}
-
 //=====================================================================
 //	Main menu
 //=====================================================================
@@ -90,8 +50,7 @@ void
 on_load3_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  create_filedialog(_("Load a circuit"), pref.last_el_file,
-                    on_circuitfile_load_selected, "*.circ");
+  load3_activate();
 }
 
 
@@ -99,10 +58,7 @@ void
 on_save4_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  if (strlen(pref.last_el_file) != 0)
-    save_circuit(pref.last_el_file);
-  else
-    on_save_as4_activate(menuitem, user_data);
+  save4_activate();
 }
 
 
@@ -110,8 +66,7 @@ void
 on_save_as4_activate                   (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  create_filedialog(_("Save circuit as"), pref.last_el_file,
-                    on_circuitfile_save_selected, "*.circ");
+  save_as4_activate();
 }
 
 //	Loads:
@@ -120,8 +75,7 @@ void
 on_load4_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  create_filedialog(_("Load load impedances"), pref.last_ld_file,
-                    on_loadfile_load_selected, "*.load");
+  load4_activate();
 }
 
 
@@ -129,10 +83,7 @@ void
 on_save5_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  if (strlen(pref.last_ld_file) != 0)
-    save_loads(pref.last_ld_file);
-  else
-    on_save_as3_activate(menuitem, user_data);
+  save5_activate();
 }
 
 
@@ -140,8 +91,23 @@ void
 on_save_as3_activate                   (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  create_filedialog(_("Save load impedances as"), pref.last_ld_file,
-                    on_loadfile_save_selected, "*.load");
+  save_as3_activate();
+}
+
+
+void
+on_csv_loads1_activate                 (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+  import_csv_activate();
+}
+
+
+void
+on_s2p_files1_activate                 (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+
 }
 
 
@@ -740,3 +706,65 @@ on_rem_cancel_btn_clicked              (GtkButton       *button,
 
 }
 
+//
+//	Import
+//
+
+
+gboolean
+on_Imports2pWindow_delete_event        (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data)
+{
+
+  return FALSE;
+}
+
+
+void
+on_Imports2pWindow_realize             (GtkWidget       *widget,
+                                        gpointer         user_data)
+{
+  Imports2pWindow_realize(widget);
+}
+
+
+void
+on_import_s2p_sel_all_btn_clicked          (GtkButton       *button,
+                                        gpointer         user_data)
+{
+
+}
+
+
+void
+on_import_s2p_sel_none_btn_clicked         (GtkButton       *button,
+                                        gpointer         user_data)
+{
+
+}
+
+
+void
+on_import_s2p_sel_invert_btn_clicked       (GtkButton       *button,
+                                        gpointer         user_data)
+{
+
+}
+
+
+void
+on_import_s2p_cancel_btn_clicked           (GtkButton       *button,
+                                        gpointer         user_data)
+{
+  import_s2p_cancel_btn_clicked();
+}
+
+
+void
+on_import_s2p_exec_btn_clicked             (GtkButton       *button,
+                                        gpointer         user_data)
+{
+  import_s2p_exec_btn_clicked();
+}
+
