@@ -335,3 +335,73 @@ on_load_nb_upd_btn_clicked             (GtkButton       *button,
 void
 on_load_nb_freq_entry_changed          (GtkEditable     *editable,
                                         gpointer         user_data);
+
+void
+on_import1_activate                    (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_import_sel_all_btn_clicked          (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_import_sel_none_btn_clicked         (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_import_sel_invert_btn_clicked       (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_import_cancel_btn_clicked           (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_import_exec_btn_clicked             (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_ImportWindow_delete_event           (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data);
+
+void
+on_ImportWindow_realize                (GtkWidget       *widget,
+                                        gpointer         user_data);
+
+void
+on_import_s2p_sel_all_btn_clicked      (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_import_s2p_sel_none_btn_clicked     (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_import_s2p_sel_invert_btn_clicked   (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_import_s2p_cancel_btn_clicked       (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_import_s2p_exec_btn_clicked         (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_Imports2pWindow_delete_event        (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data);
+
+void
+on_Imports2pWindow_realize             (GtkWidget       *widget,
+                                        gpointer         user_data);
+
+void
+on_csv_loads1_activate                 (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_s2p_files1_activate                 (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
