@@ -35,7 +35,7 @@
 #include "global.h"
 #include "load.h"
 #include "log.h"
-#include "aux.h"
+#include "misc.h"
 #include "main.h"
 #include "chart_def.h"
 #include "chart.h"
@@ -116,7 +116,10 @@ set_chart_background_bitmap(char *bgf)
     fprintf(stderr, "%s\n", bgf);
 
   chart_pxm = gdk_pixbuf_new_from_file(bgf, NULL);
-  if (!chart_pxm) printf(_("Can't load the chart background\n"));
+  if (!chart_pxm) {
+    printf(_("Can't load the chart background\n"));
+    return;
+  }
   chartw = gdk_pixbuf_get_width(chart_pxm);
   charth = gdk_pixbuf_get_height(chart_pxm);
 
@@ -315,7 +318,7 @@ update_cursor_values(int x, int y)
   g_free(bff);
 
   w = lookup_widget(MainWindow, "stat_zpol_lbl");
-  bff = g_strdup_printf("<span font_desc=\"%s\">%.2lf &lt;%.2lf&#176;</span>",
+  bff = g_strdup_printf("<span font_desc=\"%s\">%7.2lf &lt;%.2lf&#176;</span>",
                pref.cursor_font, cabs(imp), carg(imp)*57.29578);
   gtk_label_set_markup(GTK_LABEL(w), bff);
   g_free(bff);
@@ -856,7 +859,10 @@ recalculate_all(void)
 void
 recalculate_all_export(void)
 {
-  if (run_filedialog(_("Postscript filename:"), pref.last_ps_file, "*.ps")) {
+  if (run_filedialog(_("Postscript filename:"), pref.last_ps_file, TRUE,
+		_("Postsript files"), "*.ps", 
+		_("All files"), "*",
+		NULL)) {
     if (g_file_test(pref.last_ps_file, G_FILE_TEST_EXISTS)) {
       if (ok_cancel_dialog(_("Confirmation"), 
           _("This file already exists.\n"
