@@ -34,9 +34,10 @@ parse_widget_by_table(conf_definition *tbl, int len, GtkWidget *ref)
 {
   GtkWidget *w;
   GList *glst;
+  GdkColor col;
   char *p;
   int d, nr;
-  guint8 cr, cg, cb, ca;
+  guint16 alpha;
 
   for (d = 0; d < len; d++) {
     w = lookup_widget(ref, tbl[d].wdg);
@@ -101,9 +102,13 @@ parse_widget_by_table(conf_definition *tbl, int len, GtkWidget *ref)
           }
           *(GList **)tbl[d].data = glst;
           break;
-      case CFM_W_COLORPICK:
-	  gnome_color_picker_get_i8(GNOME_COLOR_PICKER(w), &cr, &cg, &cb, &ca);
-          *(int *)tbl[d].data = cr*0x1000000 + cg*0x10000 + cb*0x100 + ca;
+      case CFM_W_COLORBUTTON:
+	  gtk_color_button_get_color(GTK_COLOR_BUTTON(w), &col);
+	  alpha = gtk_color_button_get_alpha(GTK_COLOR_BUTTON(w));
+          *(int *)tbl[d].data =	(col.red >> 8)  *0x1000000 + 
+				(col.green >> 8)*0x10000 + 
+				(col.blue >> 8) *0x100 + 
+				(alpha >> 8);
           break;
       case CFM_W_FONTBUTTON:
           strcpy((char *)tbl[d].data,
@@ -119,8 +124,9 @@ load_widget_by_table(conf_definition *tbl, int len, GtkWidget *ref)
 {
   GtkWidget *w;
   GList *glst;
+  GdkColor col;
   int d, nr;
-  guint8 cr, cg, cb, ca;
+  guint16 alpha;
   double val;
   char bff[15], *str[1], *p;
 
@@ -186,12 +192,13 @@ load_widget_by_table(conf_definition *tbl, int len, GtkWidget *ref)
             gtk_clist_append(GTK_CLIST(w), str);
           }
           break;
-      case CFM_W_COLORPICK:
-          ca =  *(guint32 *)tbl[d].data        & 0xff;
-          cb = (*(guint32 *)tbl[d].data >>  8) & 0xff;
-          cg = (*(guint32 *)tbl[d].data >> 16) & 0xff;
-          cr = (*(guint32 *)tbl[d].data >> 24) & 0xff;
-          gnome_color_picker_set_i8(GNOME_COLOR_PICKER(w), cr, cg, cb, ca);
+      case CFM_W_COLORBUTTON:
+          alpha     = ( *(guint32 *)tbl[d].data        & 0xff) << 8;
+          col.blue  = ((*(guint32 *)tbl[d].data >>  8) & 0xff) << 8;
+          col.green = ((*(guint32 *)tbl[d].data >> 16) & 0xff) << 8;
+          col.red   = ((*(guint32 *)tbl[d].data >> 24) & 0xff) << 8;
+          gtk_color_button_set_color(GTK_COLOR_BUTTON(w), &col);
+	  gtk_color_button_set_alpha(GTK_COLOR_BUTTON(w), alpha);
           break;
       case CFM_W_FONTBUTTON:
           gtk_font_button_set_font_name(GTK_FONT_BUTTON(w),
