@@ -32,7 +32,7 @@
 #include "main.h"
 #include "global.h"
 #include "chart.h"
-#include "aux.h"
+#include "misc.h"
 #include "element.h"
 
 typedef struct {
@@ -124,6 +124,40 @@ gboolean	elements_changed = FALSE;
 el_definition act_el = {-1, 0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0};
 
 
+void
+load3_activate(void)
+{
+  if (run_filedialog(_("Load a circuit"), pref.last_el_file, TRUE, 
+		_("linSmith circuits"), "*.circ", 
+		_("All files"), "*",
+		NULL)) {
+    load_circuit(pref.last_el_file);
+    save_file_paths();
+  }
+}
+
+void
+save4_activate(void)
+{
+  if (strlen(pref.last_el_file) != 0)
+    save_circuit(pref.last_el_file);
+  else
+    save_as4_activate();
+}
+
+void
+save_as4_activate(void)
+{
+  if (run_filedialog(_("Save circuit as"), pref.last_el_file, FALSE,
+		_("linSmith circuits"), "*.circ", 
+		_("All files"), "*",
+		NULL)) {
+    save_circuit(pref.last_el_file);
+    save_file_paths();
+  }
+}
+
+
 void
 initialize_elementtable(void)
 {
