@@ -42,7 +42,7 @@ conf_definition preftable[] = {
 
   {CFM_W_ENTRY_DOUBLE,  "conf_swr_entry",        &pref.swr_circle, 2,
    CFM_T_DOUBLE,        "global/swr_circle",     0, "2.0"},
-  {CFM_W_COLORPICK,     "conf_swrcircle_cpick",  &pref.swr_color, 0,
+  {CFM_W_COLORBUTTON,   "conf_swrcircle_colbtn", &pref.swr_color, 0,
    CFM_T_INT,           "aspect/swr_color",      0, "-16776961"},
   {CFM_W_CBTN,          "conf_swr_cbtn",         &pref.show_swr, 0,
    CFM_T_CHAR,          "global/show_swr",       0, "1"},
@@ -51,7 +51,7 @@ conf_definition preftable[] = {
 
   {CFM_W_CBTN,          "conf_g1_cbtn",          &pref.show_g1, 0,
    CFM_T_CHAR,          "global/show_g1",        0, "1"},
-  {CFM_W_COLORPICK,     "conf_g1circle_cpick",   &pref.g1_color, 0,
+  {CFM_W_COLORBUTTON,   "conf_g1circle_colbtn",  &pref.g1_color, 0,
    CFM_T_INT,           "aspect/g1_color",       0, "-1381126657"},
   {CFM_W_CBTN,          "use_bitmap_cbtn",       &pref.use_bitmap, 0,
    CFM_T_CHAR,          "global/use_bitmap",     0, "1"},
@@ -69,29 +69,29 @@ conf_definition preftable[] = {
   {CFM_W_SPBTN_INT,     "conf_final_spbtn",      &pref.point_size[ZPT_FINAL], 0,
    CFM_T_INT,           "aspect/final_size",     0, "8"},
 
-  {CFM_W_COLORPICK,     "conf_load_cpick",       &pref.point_color[ZPT_LOAD], 0,
+  {CFM_W_COLORBUTTON,   "conf_load_colbtn",      &pref.point_color[ZPT_LOAD], 0,
    CFM_T_INT,           "aspect/load_color",     0, "-65281"},
-  {CFM_W_COLORPICK,     "conf_point_cpick",      &pref.point_color[ZPT_INT], 0,
+  {CFM_W_COLORBUTTON,   "conf_point_colbtn",     &pref.point_color[ZPT_INT], 0,
    CFM_T_INT,           "aspect/point_color",    0, "16711935"},
-  {CFM_W_COLORPICK,     "conf_final_cpick",      &pref.point_color[ZPT_FINAL], 0,
+  {CFM_W_COLORBUTTON,   "conf_final_colbtn",     &pref.point_color[ZPT_FINAL], 0,
    CFM_T_INT,           "aspect/final_color",    0, "-16645889"},
 
-  {CFM_W_COLORPICK,     "conf_z_arc_cpick",      &pref.arc_color[Z_ARC], 0,
+  {CFM_W_COLORBUTTON,   "conf_z_arc_colbtn",     &pref.arc_color[Z_ARC], 0,
    CFM_T_INT,           "aspect/z_arc_color",    0, "-9210881"},
-  {CFM_W_COLORPICK,     "conf_y_arc_cpick",      &pref.arc_color[Y_ARC], 0,
+  {CFM_W_COLORBUTTON,   "conf_y_arc_colbtn",     &pref.arc_color[Y_ARC], 0,
    CFM_T_INT,           "aspect/y_arc_color",    0, "-2139029505"},
-  {CFM_W_COLORPICK,     "conf_line_arc_cpick",   &pref.arc_color[K_ARC], 0,
+  {CFM_W_COLORBUTTON,   "conf_line_arc_colbtn",  &pref.arc_color[K_ARC], 0,
    CFM_T_INT,           "aspect/line_arc_color", 0, "1590583039"},
-  {CFM_W_COLORPICK,     "conf_zy_line_cpick",    &pref.arc_color[ZY_LINE], 0,
+  {CFM_W_COLORBUTTON,   "conf_zy_line_colbtn",   &pref.arc_color[ZY_LINE], 0,
    CFM_T_INT,           "aspect/zy_line_color", 0, "-1482184705"},
 
-  {CFM_W_COLORPICK,     "conf_r_arc_cpick",      &pref.arc_color[R_ARC], 0,
+  {CFM_W_COLORBUTTON,   "conf_r_arc_colbtn",     &pref.arc_color[R_ARC], 0,
    CFM_T_INT,           "aspect/r_arc_color",    0, "-9210881"},
-  {CFM_W_COLORPICK,     "conf_r_arc_bold_cpick", &pref.arc_color[RB_ARC], 0,
+  {CFM_W_COLORBUTTON,   "conf_r_arc_bold_colbtn", &pref.arc_color[RB_ARC], 0,
    CFM_T_INT,           "aspect/rb_arc_color",    0, "-2139029505"},
-  {CFM_W_COLORPICK,     "conf_x_arc_cpick",      &pref.arc_color[X_ARC], 0,
+  {CFM_W_COLORBUTTON,   "conf_x_arc_colbtn",     &pref.arc_color[X_ARC], 0,
    CFM_T_INT,           "aspect/x_arc_color",    0, "-9210881"},
-  {CFM_W_COLORPICK,     "conf_x_arc_bold_cpick", &pref.arc_color[XB_ARC], 0,
+  {CFM_W_COLORBUTTON,   "conf_x_arc_bold_colbtn", &pref.arc_color[XB_ARC], 0,
    CFM_T_INT,           "aspect/xb_arc_color",   0, "-2139029505"},
 
   // Screen bitmap background
@@ -106,14 +106,14 @@ conf_definition preftable[] = {
    CFM_T_DOUBLE,        "chart/y_offs",          0, "0"},
 
   // Screen vector background
-  {CFM_W_COLORPICK,     "conf_vecbg_cpick",	 &pref.vec_background, 0,
+  {CFM_W_COLORBUTTON,   "conf_vecbg_colbtn",	 &pref.vec_background, 0,
    CFM_T_INT,           "aspect/vecbg_color",    0, "0xf0ffffff"},
   {CFM_W_ENTRY_INT,	"conf_vecbg_size_entry", &pref.vec_bg_radius, 0,
    CFM_T_INT,		"aspect/vecbg_size",     0, "250"},
 
   {CFM_W_FONTBUTTON,    "conf_font_fpick",       &pref.vec_font_name, 0,
    CFM_T_STR,           "aspect/font",           0, "Helvetica 8"},
-  {CFM_W_COLORPICK,     "conf_font_cpick",       &pref.vec_font_color, 0,
+  {CFM_W_COLORBUTTON,   "conf_font_colbtn",      &pref.vec_font_color, 0,
    CFM_T_INT,           "aspect/font_color",     0, "-9210881"},
 
   // Printer setup
@@ -128,7 +128,7 @@ conf_definition preftable[] = {
 
   // Printer chart background properties
   // R arcs - normal
-  {CFM_W_COLORPICK,     "prt_r_arc_cpick",
+  {CFM_W_COLORBUTTON,   "prt_r_arc_colbtn",
 			&pref.prt_arc_color[R_ARC],  0,
    CFM_T_INT,           "print/bgarc_color_r",       0, "-4629761"},
   {CFM_W_SPBTN_DOUBLE,  "prt_r_arc_spbtn",
@@ -136,7 +136,7 @@ conf_definition preftable[] = {
    CFM_T_DOUBLE,        "print/bgarc_size_r",        0, "0.1"},
 
   // R arcs - bold
-  {CFM_W_COLORPICK,     "prt_r_arc_bold_cpick",
+  {CFM_W_COLORBUTTON,   "prt_r_arc_bold_colbtn",
 			&pref.prt_arc_color[RB_ARC], 0,
    CFM_T_INT,           "print/bgarc_bold_color_r",  0, "-91225345"},
   {CFM_W_SPBTN_DOUBLE,  "prt_r_arc_bold_spbtn",
@@ -144,7 +144,7 @@ conf_definition preftable[] = {
    CFM_T_DOUBLE,        "print/bgarc_bold_size_r",   0, "0.2"},
 
   // X arcs - normal
-  {CFM_W_COLORPICK,     "prt_x_arc_cpick",
+  {CFM_W_COLORBUTTON,   "prt_x_arc_colbtn",
    			&pref.prt_arc_color[X_ARC],  0,
    CFM_T_INT,           "print/bgarc_color_x",       0, "-5921281"},
   {CFM_W_SPBTN_DOUBLE,  "prt_x_arc_spbtn",
@@ -152,7 +152,7 @@ conf_definition preftable[] = {
    CFM_T_DOUBLE,        "print/bgarc_size_x",        0, "0.1"},
 
   // X arcs - bold
-  {CFM_W_COLORPICK,     "prt_x_arc_bold_cpick",
+  {CFM_W_COLORBUTTON,   "prt_x_arc_bold_colbtn",
    			&pref.prt_arc_color[XB_ARC], 0,
    CFM_T_INT,           "print/bgarc_bold_color_x",  0, "-10460929"},
   {CFM_W_SPBTN_DOUBLE,  "prt_x_arc_bold_spbtn",
@@ -161,13 +161,13 @@ conf_definition preftable[] = {
 
   // Actual (print) plot properties - points
   // Load points
-  {CFM_W_COLORPICK,     "prt_ldfill_cpick",
+  {CFM_W_COLORBUTTON,   "prt_ldfill_colbtn",
 			&pref.prt_fill_color[ZPT_LOAD], 0,
    CFM_T_INT,           "print/ldfill_color",        0, "-65281"},
   {CFM_W_SPBTN_DOUBLE,  "prt_lddiam_spbtn",
 			&pref.prt_diam[ZPT_LOAD],    0,
    CFM_T_DOUBLE,        "print/lddiam",              0, "2.0"},
-  {CFM_W_COLORPICK,     "prt_ldbrdr_cpick",
+  {CFM_W_COLORBUTTON,   "prt_ldbrdr_colbtn",
 			&pref.prt_brdr_color[ZPT_LOAD], 0,
    CFM_T_INT,           "print/ldbrdr_color",        0, "-6160129"},
   {CFM_W_SPBTN_DOUBLE,  "prt_ldbrdr_spbtn",
@@ -175,13 +175,13 @@ conf_definition preftable[] = {
    CFM_T_DOUBLE,        "print/ldbrdr",              0, "0.2"},
 
   // Intermediate points
-  {CFM_W_COLORPICK,     "prt_intfill_cpick",
+  {CFM_W_COLORBUTTON,   "prt_intfill_colbtn",
 			&pref.prt_fill_color[ZPT_INT], 0,
    CFM_T_INT,           "print/intfill_color",       0, "16711935"},
   {CFM_W_SPBTN_DOUBLE,  "prt_intdiam_spbtn",
 			&pref.prt_diam[ZPT_INT],     0,
    CFM_T_DOUBLE,        "print/intdiam",             0, "1.0"},
-  {CFM_W_COLORPICK,     "prt_intbrdr_cpick",
+  {CFM_W_COLORBUTTON,   "prt_intbrdr_colbtn",
 			&pref.prt_brdr_color[ZPT_INT], 0,
    CFM_T_INT,           "print/intbrdr_color",       0, "7210751"},
   {CFM_W_SPBTN_DOUBLE,  "prt_intbrdr_spbtn",
@@ -189,10 +189,10 @@ conf_definition preftable[] = {
    CFM_T_DOUBLE,        "print/intbrdr",             0, "0.1"},
 
   // Final points
-  {CFM_W_COLORPICK,     "prt_finalfill_cpick",
+  {CFM_W_COLORBUTTON,   "prt_finalfill_colbtn",
 			&pref.prt_fill_color[ZPT_FINAL], 0,
    CFM_T_INT,           "print/finalfill_color",     0, "-16776961"},
-  {CFM_W_COLORPICK,     "prt_finalbrdr_cpick",
+  {CFM_W_COLORBUTTON,   "prt_finalbrdr_colbtn",
 			&pref.prt_brdr_color[ZPT_FINAL], 0,
    CFM_T_INT,           "print/finalbrdr_color",     0, "-1275068161"},
   {CFM_W_SPBTN_DOUBLE,  "prt_finaldiam_spbtn",
@@ -205,7 +205,7 @@ conf_definition preftable[] = {
 
   // Actual plot properties - arcs
   // Z - arcs
-  {CFM_W_COLORPICK,     "prt_z_arc_cpick",
+  {CFM_W_COLORBUTTON,   "prt_z_arc_colbtn",
                         &pref.prt_arc_color[Z_ARC],  0,
    CFM_T_INT,           "print/arc_color_z",         0, "-6576641"},
   {CFM_W_SPBTN_DOUBLE,  "prt_z_arc_spbtn",
@@ -213,7 +213,7 @@ conf_definition preftable[] = {
    CFM_T_DOUBLE,        "print/arc_z",               0, "0.4"},
 
   // Y - arcs
-  {CFM_W_COLORPICK,     "prt_y_arc_cpick",
+  {CFM_W_COLORBUTTON,   "prt_y_arc_colbtn",
                         &pref.prt_arc_color[Y_ARC],  0,
    CFM_T_INT,           "print/arc_color_y",         0, "-1212678145"},
   {CFM_W_SPBTN_DOUBLE,  "prt_y_arc_spbtn",
@@ -221,7 +221,7 @@ conf_definition preftable[] = {
    CFM_T_DOUBLE,        "print/arc_y",               0, "0.4"},
 
   // Line - arcs
-  {CFM_W_COLORPICK,     "prt_line_arc_cpick",
+  {CFM_W_COLORBUTTON,   "prt_line_arc_colbtn",
                         &pref.prt_arc_color[K_ARC],  0,
    CFM_T_INT,           "print/arc_color_line",      0, "-1308642817"},
   {CFM_W_SPBTN_DOUBLE,  "prt_line_arc_spbtn",
@@ -229,7 +229,7 @@ conf_definition preftable[] = {
    CFM_T_DOUBLE,        "print/arc_line",            0, "0.4"},
 
   // Z-Y connection lines
-  {CFM_W_COLORPICK,     "prt_zy_line_cpick",
+  {CFM_W_COLORBUTTON,   "prt_zy_line_colbtn",
                         &pref.prt_arc_color[ZY_LINE], 0,
    CFM_T_INT,           "print/arc_color_zyline",    0, "-1179010561"},
   {CFM_W_SPBTN_DOUBLE,  "prt_zy_line_spbtn",
@@ -238,13 +238,13 @@ conf_definition preftable[] = {
 
   // Misc
   // SWR circle
-  {CFM_W_COLORPICK,     "prt_swrcircle_cpick",   &pref.prt_swr_color, 0,
+  {CFM_W_COLORBUTTON,   "prt_swrcircle_colbtn",  &pref.prt_swr_color, 0,
    CFM_T_INT,           "print/swr_color",           0, "-8750337"},
   {CFM_W_SPBTN_DOUBLE,  "prt_swrcircle_spbtn",   &pref.prt_swr_size, 0,
    CFM_T_DOUBLE,        "print/swr_size",            0, "0.1"},
 
   // G=1 circle
-  {CFM_W_COLORPICK,     "prt_g1circle_cpick",    &pref.prt_g1_color, 0,
+  {CFM_W_COLORBUTTON,   "prt_g1circle_colbtn",   &pref.prt_g1_color, 0,
    CFM_T_INT,           "print/g1_color",            0, "-1010580481"},
   {CFM_W_SPBTN_DOUBLE,  "prt_g1circle_spbtn",    &pref.prt_g1_size, 0,
    CFM_T_DOUBLE,        "print/g1_size",             0, "0.1"},
@@ -252,7 +252,7 @@ conf_definition preftable[] = {
   // Font
   {CFM_W_ENTRY_STR,     "prt_font_entry",        &pref.prt_font_name, 0,
    CFM_T_STR,           "print/prt_font_name",       0, "Helvetica"},
-  {CFM_W_COLORPICK,     "prt_font_cpick",        &pref.prt_font_color, 0,
+  {CFM_W_COLORBUTTON,   "prt_font_colbtn",       &pref.prt_font_color, 0,
    CFM_T_INT,           "print/font_color",          0, "-1097924353"},
   {CFM_W_SPBTN_DOUBLE,  "prt_fontsize_spbtn",    &pref.prt_font_size, 0,
    CFM_T_DOUBLE,        "print/font_size",           0, "2.0"},
@@ -274,6 +274,7 @@ conf_definition preftable[] = {
    CFM_T_DOUBLE,        "noisebr/extender",      0, "100.0"},
   {CFM_W_CBOX,          "nb_type_cbbox",         &pref.nb_type, 0,
    CFM_T_INT,           "noisebr/type",          0, "0"},
+
   // Files tab: last used filenames
   {CFM_W_ENTRY_STR,     "conf_last_ld_entry",    &pref.last_ld_file, 0,
    CFM_T_STR,           "files/last_load_file",  0, ""},
@@ -281,6 +282,12 @@ conf_definition preftable[] = {
    CFM_T_STR,           "files/last_elem_file",  0, ""},
   {CFM_W_ENTRY_STR,     "conf_last_ps_entry",    &pref.last_ps_file, 0,
    CFM_T_STR,           "files/last_ps_file",    0, ""},
+  {CFM_W_ENTRY_STR,     "conf_last_csv_entry",   &pref.last_csv_file, 0,
+   CFM_T_STR,           "files/last_csv_file",   0, ""},
+
+  // File tab: CSV separator character
+  {CFM_W_ENTRY_STR,	"conf_csv_sep_entry", 	&pref.csv_sep, 0,
+   CFM_T_STR,		"files/csv_sep",	0, ","}
 };
 #define preflen (sizeof(preftable)/sizeof(conf_definition))
 
