@@ -49,6 +49,7 @@ typedef struct {
   char   last_el_file[200],
   	 last_ld_file[200],
          last_ps_file[200],
+	 last_csv_file[200],
   	 chart[200],
 
 	 cursor_font[80],
@@ -116,6 +117,9 @@ typedef struct {
 	 rem_inpipe[120],
   	 rem_mode;
   int	 rem_timeout;
+
+  // CSV parameters
+  char	 csv_sep[2];
   
   // These are local (non-saveable) parameters
   
